@@ -145,10 +145,10 @@ pub enum Dimension {
 /// Thus, **Positionable** can be implemented for *all* types that implement **Widget**.
 pub trait Positionable: Sized {
     /// Build with the given **Position** along the *x* axis.
-    fn x_position(self, Position) -> Self;
+    fn x_position(self, x: Position) -> Self;
 
     /// Build with the given **Position** along the *y* axis.
-    fn y_position(self, Position) -> Self;
+    fn y_position(self, y: Position) -> Self;
 
     /// Get the **Position** along the *x* axis.
     fn get_x_position(&self, ui: &Ui) -> Position;
